===============
Getting started
===============

Installation
============

To install BMicro, use one of the following methods:
    
* from `PyPI <https://pypi.python.org/pypi/bmicro>`_:
    ``pip install bmicro``
* from `sources <https://github.com/BrillouinMicroscopy/BMicro>`_:
    ``pip install .``


Citing BMicro
============
If you use BMicro in a scientific publication, please cite it with:

.. pull-quote::

   BMicro developers (2022), BMicro version X.X.X: Python library for the
   post-measurement analysis of Brillouin microscopy data sets
   [Software]. Available at https://github.com/BrillouinMicroscopy/BMicro.
